@@ -34,28 +34,28 @@
 #include "tabcontextmenu.h"
 #include "tabbar.h"
 
-#include <QDesktopWidget>
 #include <QDialogButtonBox>
 #include <QStackedWidget>
 #include <QDialog>
 #include <QTimer>
 #include <QLabel>
 #include <QMimeData>
+#include <QRegExp>
 
 
-TLDExtractor* TabManagerWidget::s_tldExtractor = 0;
+TLDExtractor* TabManagerWidget::s_tldExtractor = nullptr;
 
 TabManagerWidget::TabManagerWidget(BrowserWindow* mainClass, QWidget* parent, bool defaultWidget)
     : QWidget(parent)
     , ui(new Ui::TabManagerWidget)
     , m_window(mainClass)
-    , m_webPage(0)
+    , m_webPage(nullptr)
     , m_isRefreshing(false)
     , m_refreshBlocked(false)
     , m_waitForRefresh(false)
     , m_isDefaultWidget(defaultWidget)
 {
-    if(s_tldExtractor == 0)
+    if(s_tldExtractor == nullptr)
     {
         s_tldExtractor = TLDExtractor::instance();
         s_tldExtractor->setDataSearchPaths(QStringList() << TabManagerPlugin::settingsPath());
@@ -107,13 +107,13 @@ QString TabManagerWidget::domainFromUrl(const QUrl &url, bool useHostName)
     QString appendString = QL1S(":");
     QString urlString = url.toString();
 
-    if (url.scheme() == "file") {
+    if (url.scheme() == QSL("file")) {
         return tr("Local File System:");
     }
-    else if (url.scheme() == "falkon" || urlString.isEmpty()) {
+    else if (url.scheme() == QSL("falkon") || urlString.isEmpty()) {
         return tr("Falkon:");
     }
-    else if (url.scheme() == "ftp") {
+    else if (url.scheme() == QSL("ftp")) {
         appendString.prepend(tr(" [FTP]"));
     }
 
@@ -122,8 +122,8 @@ QString TabManagerWidget::domainFromUrl(const QUrl &url, bool useHostName)
         return urlString.append(appendString);
     }
 
-    if (useHostName || host.contains(QRegExp(R"(^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$)"))) {
-        if (host.startsWith("www.", Qt::CaseInsensitive)) {
+    if (useHostName || QRegExp(QSL(R"(^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$)")).indexIn(host) >= 0) {
+        if (host.startsWith(QSL("www."), Qt::CaseInsensitive)) {
             host.remove(0, 4);
         }
 
@@ -322,15 +322,15 @@ void TabManagerWidget::customContextMenuRequested(const QPoint &pos)
     menu->addMenu(&groupTypeSubmenu);
 
     if (m_isDefaultWidget) {
-        menu->addAction(QIcon(":/tabmanager/data/side-by-side.png"), tr("&Show side by side"), this, &TabManagerWidget::showSideBySide)->setObjectName("sideBySide");
+        menu->addAction(QIcon(QSL(":/tabmanager/data/side-by-side.png")), tr("&Show side by side"), this, &TabManagerWidget::showSideBySide)->setObjectName("sideBySide");
     }
 
     menu->addSeparator();
 
     if (isTabSelected()) {
-        menu->addAction(QIcon(":/tabmanager/data/tab-detach.png"), tr("&Detach checked tabs"), this, &TabManagerWidget::processActions)->setObjectName("detachSelection");
-        menu->addAction(QIcon(":/tabmanager/data/tab-bookmark.png"), tr("Book&mark checked tabs"), this, &TabManagerWidget::processActions)->setObjectName("bookmarkSelection");
-        menu->addAction(QIcon(":/tabmanager/data/tab-close.png"), tr("&Close checked tabs"), this, &TabManagerWidget::processActions)->setObjectName("closeSelection");
+        menu->addAction(QIcon(QSL(":/tabmanager/data/tab-detach.png")), tr("&Detach checked tabs"), this, &TabManagerWidget::processActions)->setObjectName("detachSelection");
+        menu->addAction(QIcon(QSL(":/tabmanager/data/tab-bookmark.png")), tr("Book&mark checked tabs"), this, &TabManagerWidget::processActions)->setObjectName("bookmarkSelection");
+        menu->addAction(QIcon(QSL(":/tabmanager/data/tab-close.png")), tr("&Close checked tabs"), this, &TabManagerWidget::processActions)->setObjectName("closeSelection");
         menu->addAction(tr("&Unload checked tabs"), this, &TabManagerWidget::processActions)->setObjectName("unloadSelection");
     }
 
@@ -356,7 +356,7 @@ void TabManagerWidget::filterChanged(const QString &filter, bool force)
             return;
         }
 
-        const QRegularExpression filterRegExp(filter.simplified().replace(QChar(' '), QLatin1String(".*"))
+        const QRegularExpression filterRegExp(filter.simplified().replace(QL1C(' '), QLatin1String(".*"))
                                               .append(QLatin1String(".*")).prepend(QLatin1String(".*")),
                                               QRegularExpression::CaseInsensitiveOption);
 
@@ -393,7 +393,7 @@ void TabManagerWidget::filterBarClosed()
 {
     ui->filterBar->clear();
     ui->filterBar->hide();
-    ui->treeWidget->setFocusProxy(0);
+    ui->treeWidget->setFocusProxy(nullptr);
     ui->treeWidget->setFocus();
 }
 
@@ -452,7 +452,7 @@ void TabManagerWidget::processActions()
 
     m_refreshBlocked = true;
 
-    QHash<BrowserWindow*, WebTab*> selectedTabs;
+    QMultiHash<BrowserWindow*, WebTab*> selectedTabs;
 
     const QString &command = sender()->objectName();
 
@@ -477,22 +477,22 @@ void TabManagerWidget::processActions()
                 continue;
             }
 
-            selectedTabs.insertMulti(mainWindow, webTab);
+            selectedTabs.insert(mainWindow, webTab);
         }
         winItem->setCheckState(0, Qt::Unchecked);
     }
 
     if (!selectedTabs.isEmpty()) {
-        if (command == "closeSelection") {
+        if (command == QSL("closeSelection")) {
             closeSelectedTabs(selectedTabs);
         }
-        else if (command == "detachSelection") {
+        else if (command == QSL("detachSelection")) {
             detachSelectedTabs(selectedTabs);
         }
-        else if (command == "bookmarkSelection") {
+        else if (command == QSL("bookmarkSelection")) {
             bookmarkSelectedTabs(selectedTabs);
         }
-        else if (command == "unloadSelection") {
+        else if (command == QSL("unloadSelection")) {
             unloadSelectedTabs(selectedTabs);
         }
     }
@@ -518,7 +518,7 @@ void TabManagerWidget::changeGroupType()
     }
 }
 
-void TabManagerWidget::closeSelectedTabs(const QHash<BrowserWindow*, WebTab*> &tabsHash)
+void TabManagerWidget::closeSelectedTabs(const QMultiHash<BrowserWindow*, WebTab*> &tabsHash)
 {
     if (tabsHash.isEmpty()) {
         return;
@@ -534,7 +534,7 @@ void TabManagerWidget::closeSelectedTabs(const QHash<BrowserWindow*, WebTab*> &t
     }
 }
 
-static void detachTabsTo(BrowserWindow* targetWindow, const QHash<BrowserWindow*, WebTab*> &tabsHash)
+static void detachTabsTo(BrowserWindow* targetWindow, const QMultiHash<BrowserWindow*, WebTab*> &tabsHash)
 {
     const QList<BrowserWindow*> &windows = tabsHash.uniqueKeys();
     for (BrowserWindow* mainWindow : windows) {
@@ -544,7 +544,7 @@ static void detachTabsTo(BrowserWindow* targetWindow, const QHash<BrowserWindow*
 
             if (mainWindow && mainWindow->tabCount() == 0) {
                 mainWindow->close();
-                mainWindow = 0;
+                mainWindow = nullptr;
             }
 
             targetWindow->tabWidget()->addView(webTab, Qz::NT_NotSelectedTab);
@@ -552,7 +552,7 @@ static void detachTabsTo(BrowserWindow* targetWindow, const QHash<BrowserWindow*
     }
 }
 
-void TabManagerWidget::detachSelectedTabs(const QHash<BrowserWindow*, WebTab*> &tabsHash)
+void TabManagerWidget::detachSelectedTabs(const QMultiHash<BrowserWindow*, WebTab*> &tabsHash)
 {
     if (tabsHash.isEmpty() ||
             (tabsHash.uniqueKeys().size() == 1 &&
@@ -561,12 +561,13 @@ void TabManagerWidget::detachSelectedTabs(const QHash<BrowserWindow*, WebTab*> &
     }
 
     BrowserWindow* newWindow = mApp->createWindow(Qz::BW_OtherRestoredWindow);
-    newWindow->move(mApp->desktop()->availableGeometry(this).topLeft() + QPoint(30, 30));
+    const QRect &availableGeometryForScreen = screen()->availableGeometry();
+    newWindow->move(availableGeometryForScreen.topLeft() + QPoint(30, 30));
 
     detachTabsTo(newWindow, tabsHash);
 }
 
-bool TabManagerWidget::bookmarkSelectedTabs(const QHash<BrowserWindow*, WebTab*> &tabsHash)
+bool TabManagerWidget::bookmarkSelectedTabs(const QMultiHash<BrowserWindow*, WebTab*> &tabsHash)
 {
     auto* dialog = new QDialog(getWindow(), Qt::WindowStaysOnTopHint | Qt::MSWindowsFixedSizeDialogHint);
     auto* layout = new QBoxLayout(QBoxLayout::TopToBottom, dialog);
@@ -608,7 +609,7 @@ bool TabManagerWidget::bookmarkSelectedTabs(const QHash<BrowserWindow*, WebTab*>
     return true;
 }
 
-void TabManagerWidget::unloadSelectedTabs(const QHash<BrowserWindow*, WebTab*> &tabsHash)
+void TabManagerWidget::unloadSelectedTabs(const QMultiHash<BrowserWindow*, WebTab*> &tabsHash)
 {
     if (tabsHash.isEmpty()) {
         return;
@@ -645,13 +646,13 @@ QTreeWidgetItem* TabManagerWidget::groupByDomainName(bool useHostName)
         for (int tab = 0; tab < tabs.count(); ++tab) {
             WebTab* webTab = tabs.at(tab);
             if (webTab->webView() && m_webPage == webTab->webView()->page()) {
-                m_webPage = 0;
+                m_webPage = nullptr;
                 continue;
             }
             QString domain = domainFromUrl(webTab->url(), useHostName);
 
             if (!tabsGroupedByDomain.contains(domain)) {
-                auto* groupItem = new TabItem(ui->treeWidget, false, false, 0, false);
+                auto* groupItem = new TabItem(ui->treeWidget, false, false, nullptr, false);
                 groupItem->setTitle(domain);
                 groupItem->setIsActiveOrCaption(true);
 
@@ -711,7 +712,7 @@ QTreeWidgetItem* TabManagerWidget::groupByWindow()
         for (int tab = 0; tab < tabs.count(); ++tab) {
             WebTab* webTab = tabs.at(tab);
             if (webTab->webView() && m_webPage == webTab->webView()->page()) {
-                m_webPage = 0;
+                m_webPage = nullptr;
                 continue;
             }
             auto* tabItem = new TabItem(ui->treeWidget, true, true, winItem);
@@ -745,13 +746,13 @@ BrowserWindow* TabManagerWidget::getWindow()
 
 TabItem::TabItem(QTreeWidget* treeWidget, bool supportDrag, bool isTab, QTreeWidgetItem* parent, bool addToTree)
     : QObject()
-    , QTreeWidgetItem(addToTree ? (parent ? parent : treeWidget->invisibleRootItem()) : 0, 1)
+    , QTreeWidgetItem(addToTree ? (parent ? parent : treeWidget->invisibleRootItem()) : nullptr, 1)
     , m_treeWidget(treeWidget)
-    , m_window(0)
-    , m_webTab(0)
+    , m_window(nullptr)
+    , m_webTab(nullptr)
     , m_isTab(isTab)
 {
-    Qt::ItemFlags flgs = flags() | (parent ? Qt::ItemIsUserCheckable : Qt::ItemIsUserCheckable | Qt::ItemIsTristate);
+    Qt::ItemFlags flgs = flags() | (parent ? Qt::ItemIsUserCheckable : Qt::ItemIsUserCheckable | Qt::ItemIsAutoTristate);
 
     if (supportDrag) {
         if (isTab) {
@@ -823,7 +824,7 @@ void TabItem::updateIcon()
             }
         }
         else {
-            setIcon(0, QIcon(":tabmanager/data/tab-pinned.png"));
+            setIcon(0, QIcon(QSL(":tabmanager/data/tab-pinned.png")));
         }
 
         if (m_webTab->isRestored())
@@ -832,7 +833,7 @@ void TabItem::updateIcon()
             setIsSavedTab(true);
     }
     else {
-        setIcon(0, QIcon(":tabmanager/data/tab-loading.png"));
+        setIcon(0, QIcon(QSL(":tabmanager/data/tab-loading.png")));
         setIsActiveOrCaption(m_webTab->isCurrentTab());
     }
 }
@@ -880,7 +881,7 @@ QStringList TabTreeWidget::mimeTypes() const
     return types;
 }
 
-QMimeData *TabTreeWidget::mimeData(const QList<QTreeWidgetItem*> items) const
+QMimeData *TabTreeWidget::mimeData(const QList<QTreeWidgetItem*> &items) const
 {
     auto* mimeData = new QMimeData();
     QByteArray encodedData;
@@ -890,7 +891,7 @@ QMimeData *TabTreeWidget::mimeData(const QList<QTreeWidgetItem*> items) const
     if (items.size() > 0) {
         auto* tabItem = static_cast<TabItem*>(items.at(0));
         if (!tabItem || !tabItem->isTab())
-            return 0;
+            return nullptr;
 
         stream << (quintptr) tabItem->window() << (quintptr) tabItem->webTab();
 
@@ -899,7 +900,7 @@ QMimeData *TabTreeWidget::mimeData(const QList<QTreeWidgetItem*> items) const
         return mimeData;
     }
 
-    return 0;
+    return nullptr;
 }
 
 bool TabTreeWidget::dropMimeData(QTreeWidgetItem *parent, int index, const QMimeData *data, Qt::DropAction action)
@@ -951,7 +952,7 @@ bool TabTreeWidget::dropMimeData(QTreeWidgetItem *parent, int index, const QMime
             }
         }
         else if (!webTab->isPinned()) {
-            QHash<BrowserWindow*, WebTab*> tabsHash;
+            QMultiHash<BrowserWindow*, WebTab*> tabsHash;
             tabsHash.insert(window, webTab);
 
             detachTabsTo(targetWindow, tabsHash);
